@@ -3,7 +3,7 @@ from whatap.trace.mod.application_wsgi import trace_handler, \
     interceptor_step_error, start_interceptor, end_interceptor
 from whatap.trace.trace_context import TraceContext
 from whatap.trace.trace_context_manager import TraceContextManager
-from whatap.net.udp_session import UdpSession
+import whatap.net.async_sender as async_sender
 from whatap.net.packet_type_enum import PacketTypeEnum
 from whatap.util.date_util import DateUtil
 import re
@@ -50,7 +50,7 @@ def intercept_execute(fn, *args, **kwargs):
             text = "graphql.execute"
             payloads = [text, '']
             ctx.elapsed = DateUtil.nowSystem() - start_time
-            UdpSession.send_packet(PacketTypeEnum.TX_METHOD, ctx, payloads)
+            async_sender.send_packet(PacketTypeEnum.TX_METHOD, ctx, payloads)
 
 def parseDocumentName(op_def):
     op = op_def.operation
@@ -114,7 +114,7 @@ def intercept_execute_method( fn, *args, **kwargs):
             
             payloads = [text, arg]
             ctx.elapsed = DateUtil.nowSystem() - start_time
-            UdpSession.send_packet(PacketTypeEnum.TX_METHOD, ctx, payloads)
+            async_sender.send_packet(PacketTypeEnum.TX_METHOD, ctx, payloads)
         
 def instrument_graphql(module):
     def wrapper(fn):
