@@ -155,7 +155,9 @@ def interceptor(rn_environ, *args, **kwargs):
     ctx.remoteIp = userid_util.getRemoteAddr(args)
 
     ctx.userAgentString = environ.get('HTTP_USER_AGENT', '')
-    ctx.referer = environ.get('HTTP_REFERER''', '')
+    ctx.referer = environ.get('HTTP_REFERER', '')
+
+
 
     if conf.trace_user_enabled:
         if conf.trace_user_using_ip:
@@ -375,7 +377,6 @@ def interceptor_db_con(fn, db_type, *args, **kwargs):
     try:
         callback = fn(*args, **kwargs)
     finally:
-
         ctx.db_opening = False
 
     if not kwargs:
@@ -387,7 +388,7 @@ def interceptor_db_con(fn, db_type, *args, **kwargs):
     text += "@"
     text += kwargs.get('host')
     text += '/'
-    text += kwargs.get('database', kwargs.get('db', kwargs.get('dbname')))
+    text += kwargs.get('database', kwargs.get('db', kwargs.get('dbname', '')))
     ctx.active_dbc = text
     ctx.lctx['dbc'] = text
 
